==> kafka-streams-0.10.0.1-cp1-sources.jar: org/apache/kafka/streams/kstream/internals/KTableSourceValueGetterSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.streams.kstream.internals;

import org.apache.kafka.streams.processor.ProcessorContext;
import org.apache.kafka.streams.state.KeyValueStore;

public class KTableSourceValueGetterSupplier<K, V> implements KTableValueGetterSupplier<K, V> {

    private final String topic;

    public KTableSourceValueGetterSupplier(String topic) {
        this.topic = topic;
    }

    public KTableValueGetter<K, V> get() {
        return new KTableSourceValueGetter();
    }

    private class KTableSourceValueGetter implements KTableValueGetter<K, V> {

        KeyValueStore<K, V> store = null;

        @SuppressWarnings("unchecked")
        public void init(ProcessorContext context) {
            store = (KeyValueStore<K, V>) context.getStateStore(topic);
        }

        public V get(K key) {
            return store.get(key);
        }

    }

}

==> kafka-streams-0.10.1.1-cp1-sources.jar: org/apache/kafka/streams/kstream/internals/KTableSourceValueGetterSupplier.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.streams.kstream.internals;

import org.apache.kafka.streams.processor.ProcessorContext;
import org.apache.kafka.streams.state.KeyValueStore;

public class KTableSourceValueGetterSupplier<K, V> implements KTableValueGetterSupplier<K, V> {

    private final String storeName;

    public KTableSourceValueGetterSupplier(String storeName) {
        this.storeName = storeName;
    }

    public KTableValueGetter<K, V> get() {
        return new KTableSourceValueGetter();
    }

    @Override
    public String[] storeNames() {
        return new String[]{storeName};
    }

    private class KTableSourceValueGetter implements KTableValueGetter<K, V> {

        KeyValueStore<K, V> store = null;

        @SuppressWarnings("unchecked")
        public void init(ProcessorContext context) {
            store = (KeyValueStore<K, V>) context.getStateStore(storeName);
        }

        public V get(K key) {
            return store.get(key);
        }

    }

}
